package VMOMI::ClusterVmComponentProtectionSettingsStorageVmReaction;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
